Waldur MasterMind
=================

Waldur MasterMind is part of the Waldur suite - https://waldur.com - for managing of hybrid cloud resources.
It is used for building marketplaces, self-service portals and for managing in-house IT resources.

License
-------
Waldur MasterMind is released under MIT license.

Documentation
-------------

Administration and usage guides can be found at http://docs.waldur.com .

Support
-------

For professional support and integration services please contact info@opennodecloud.com.
